@@ -32,15 +32,15 @@ MyPropertySheet::MyPropertySheet (
     wxWindow *parent,
     XmlCtrlProperties& propertiesParameter,
     wxString& applicationDirParameter,
-    bool rememberOpenTabsParameter,
-    bool libxmlNetAccessParameter,
-    bool singleInstanceCheckParameter,
-    bool saveBomParameter,
-    bool unlimitedUndoParameter,
-    bool restoreLayoutParameter,
-    bool expandInternalEntitiesParameter,
-    bool showFullPathOnFrameParameter,
-    int lang,
+    bool &rememberOpenTabsParameter,
+    bool &libxmlNetAccessParameter,
+    bool &singleInstanceCheckParameter,
+    bool &saveBomParameter,
+    bool &unlimitedUndoParameter,
+    bool &restoreLayoutParameter,
+    bool &expandInternalEntitiesParameter,
+    bool &showFullPathOnFrameParameter,
+    int &lang,
     const std::set<const wxLanguageInfo *> &translations,
     wxWindowID id,
     wxString title,
@@ -49,8 +49,17 @@ MyPropertySheet::MyPropertySheet (
     long style
     )
 	: wxPropertySheetDialog ( parent, id, title, position, size, style )
+	, lang ( lang )
 	, properties ( propertiesParameter )
 	, applicationDir ( applicationDirParameter )
+	, singleInstanceCheck ( singleInstanceCheckParameter )
+	, rememberOpenTabs ( rememberOpenTabsParameter )
+	, libxmlNetAccess ( libxmlNetAccessParameter )
+	, saveBom ( saveBomParameter )
+	, unlimitedUndo ( unlimitedUndoParameter )
+	, restoreLayout ( restoreLayoutParameter )
+	, expandInternalEntities ( expandInternalEntitiesParameter )
+	, showFullPathOnFrame ( showFullPathOnFrameParameter )
 {
 	CreateButtons ( wxOK | wxCANCEL );
 
@@ -167,7 +176,7 @@ MyPropertySheet::MyPropertySheet (
 	    wxID_ANY );
 	languageBox->SetExtraStyle ( languageBox->GetExtraStyle() | wxCB_SORT );
 
-	languageBox->Append ( _ ( "Default" ), ( void* ) wxLANGUAGE_ENGLISH_US );
+	languageBox->Append ( _ ( "Default" ), ( void* ) wxLANGUAGE_DEFAULT );
 	languageBox->SetSelection ( 0 );
 
 	int index;
@@ -181,7 +190,7 @@ MyPropertySheet::MyPropertySheet (
 	}
 
 	libxmlNetAccessBox = new wxCheckBox (
-	    generalPanel, wxID_ANY, _ ( "&Enable network access for DTD validation" ) );
+	    generalPanel, wxID_ANY, _ ( "&Enable network access for XML validation" ) );
 	libxmlNetAccessBox->SetValue ( libxmlNetAccessParameter );
 	expandInternalEntitiesBox = new wxCheckBox (
 	    generalPanel, wxID_ANY, _ ( "E&xpand internal entities on open" ) );
@@ -241,6 +250,15 @@ MyPropertySheet::~MyPropertySheet()
 
 void MyPropertySheet::OnOk ( wxCommandEvent& e )
 {
+	wxString testDir = applicationDirEdit->GetValue();
+	if ( !wxDirExists ( testDir ) )
+	{
+		wxMessageBox ( _ ( "Cannot access application directory" ), _ ( "Options" ) );
+		// tbd: show general tab
+		return;
+	}
+	applicationDir = testDir;
+
 	properties.completion = completionBox->GetValue();
 	properties.fold = foldBox->GetValue();
 	properties.number = numberBox->GetValue();
@@ -255,16 +273,6 @@ void MyPropertySheet::OnOk ( wxCommandEvent& e )
 	properties.font = fontBox->GetStringSelection();
 	properties.highlightSyntax = highlightSyntaxBox->GetValue();
 
-	wxString testDir = applicationDirEdit->GetValue();
-	if ( !wxFileName::DirExists ( testDir ) )
-	{
-		wxMessageBox ( _ ( "Cannot access application directory" ), _ ( "Options" ) );
-		// tbd: show general tab
-		return;
-	}
-	else
-		applicationDir = testDir;
-
 	singleInstanceCheck = singleInstanceCheckBox->GetValue();
 	restoreLayout = restoreLayoutBox->GetValue();
 	rememberOpenTabs = rememberOpenTabsBox->GetValue();
@@ -276,71 +284,17 @@ void MyPropertySheet::OnOk ( wxCommandEvent& e )
 
 	int languageChoice = languageBox->GetSelection();
 	if ( languageChoice != wxNOT_FOUND )
-		lang = (wxIntPtr)languageBox->GetClientData(languageChoice);
+		lang =  ( wxIntPtr ) languageBox->GetClientData ( languageChoice );
 	else
-		lang = wxLANGUAGE_ENGLISH_US;
+		lang = wxLANGUAGE_DEFAULT;
 
 	e.Skip();
 }
 
 void MyPropertySheet::OnApplicationDirBrowse ( wxCommandEvent& e )
 {
-	wxDirDialog *browseDialog = new wxDirDialog ( this );
-	if ( browseDialog->ShowModal() == wxID_OK )
-		applicationDirEdit->SetValue ( browseDialog->GetPath() );
-}
-
-XmlCtrlProperties MyPropertySheet::getProperties()
-{
-	return properties;
-}
-
-wxString MyPropertySheet::getApplicationDir()
-{
-	return applicationDir;
-}
-
-bool MyPropertySheet::getSingleInstanceCheck()
-{
-	return singleInstanceCheck;
-}
-
-bool MyPropertySheet::getRememberOpenTabs()
-{
-	return rememberOpenTabs;
-}
-
-bool MyPropertySheet::getLibxmlNetAccess()
-{
-	return libxmlNetAccess;
-}
-
-bool MyPropertySheet::getSaveBom()
-{
-	return saveBom;
-}
-
-bool MyPropertySheet::getUnlimitedUndo()
-{
-	return unlimitedUndo;
-}
-
-int MyPropertySheet::getLang()
-{
-	return lang;
-}
-
-bool MyPropertySheet::getRestoreLayout()
-{
-	return restoreLayout;
-}
-
-bool MyPropertySheet::getExpandInternalEntities()
-{
-	return expandInternalEntities;
-}
-
-bool MyPropertySheet::getShowFullPathOnFrame()
-{
-	return showFullPathOnFrame;
+	wxDirDialog browseDir ( this );
+	browseDir.SetPath ( applicationDirEdit->GetValue() );
+	if ( browseDir.ShowModal() == wxID_OK )
+		applicationDirEdit->SetValue ( browseDir.GetPath() );
 }
