@@ -73,8 +73,8 @@ class StyleDialog : public wxDialog
 		    const wxString& ruleSetPresetParameter,
 		    const wxString& filterPresetParameter,
   #ifdef __WXMSW__
-            const std::string& aspellDataPath,
-            const std::string& aspellDictPath,
+            const wxString& aspellDataPath,
+            const wxString& aspellDictPath,
   #endif
 		    int type = ID_TYPE_STYLE,
 		    bool readOnlyParameter = false,
@@ -118,7 +118,8 @@ class StyleDialog : public wxDialog
 		wxComboBox *ruleSetCombo, *filterCombo;
 		wxListCtrl *table;
 		wxStatusBar *status;
-		std::string bufferUtf8, aspellDataPath, aspellDictPath;
+		std::string bufferUtf8;
+		wxString aspellDataPath, aspellDictPath;
 		std::set<wxString> tempFiles;
 		wxString fileName, ruleSetDirectory, filterDirectory;
 		wxString ruleSetPreset, filterPreset;
