@@ -1,4 +1,5 @@
-#include "wx/wx.h"
+#include <wx/wx.h>
+#include <wx/textbuf.h>
 #include "xmlctrl.h"
 #include "validationthread.h"
 #include "wrapxerces.h"
@@ -13,7 +14,7 @@ DEFINE_EVENT_TYPE(wxEVT_COMMAND_VALIDATION_COMPLETED);
 ValidationThread::ValidationThread (
 	wxEvtHandler *handler,
 	const char *buffer,
-	const char *system )
+	const wxString &system )
 	: wxThread ( wxTHREAD_JOINABLE )
 	, mStopping ( false )
 {
@@ -34,14 +35,21 @@ void *ValidationThread::Entry()
 	
 	if ( TestDestroy()  )
 	{
+		myBuffer.clear();
 		return NULL;
 	}
 
 	myIsSucceeded = validator->validateMemory (
 		myBuffer.c_str(),
 		myBuffer.size(),
-		mySystem.c_str(),
-		this );
+		mySystem,
+		this,
+		// Don't be too harsh to new created documents, which may haven't
+		// associated any schema yet
+		/*forceCheckGrammar*/false,
+		wxTextBuffer::GetEOL() );
+
+	myBuffer.clear();
 
 	if ( TestDestroy() )
 	{
