@@ -103,11 +103,9 @@ bool WrapDaisy::run (
         return false;
     }
 
-    std::string output, stdStylesheet, stdFileIn;
-    stdStylesheet = stylesheet.mb_str ( wxConvUTF8 );
-    stdFileIn = fileIn.mb_str ( wxConvUTF8 );
+    std::string output;
 
-    if ( !stdStylesheet.empty() ) // stylesheet found
+    if ( !stylesheet.empty() ) // stylesheet found
     {
         // #1: convert to canonical XHTML
 #if wxCHECK_VERSION(2,9,0)
@@ -126,12 +124,11 @@ bool WrapDaisy::run (
     
         WrapLibxml wrapLibxml;
             
-        bool success = wrapLibxml.xslt ( stdStylesheet, stdFileIn );
+        bool success = wrapLibxml.xslt ( stylesheet, fileIn );
        
         if ( !success )
         {
-            std::string stdError = wrapLibxml.getLastError();
-            error = wxString ( stdError.c_str(), wxConvUTF8, stdError.size() );
+            error = wrapLibxml.getLastError();
             return false;   
         }
         
@@ -145,9 +142,9 @@ bool WrapDaisy::run (
     }
     else // no stylesheet
     {
-        BinaryFile bf( stdFileIn.c_str() );
-	if ( !bf.getData() )
-	{
+        BinaryFile bf( fileIn );
+        if ( !bf.getData() )
+        {
             output.append ( bf.getData(), bf.getDataLen() );
             error = _( "Cannot read [b]" ) + fileIn + ( _("[/b]") );
             return false;
@@ -727,15 +724,13 @@ bool WrapDaisy::run (
         _T("z3986") + wxFileName::GetPathSeparator();
     fileWithSmilAttribs = folderWithSmilFile + fn.GetFullName();
 
-    std::string file = ( const char *) fileWithSmilAttribs.mb_str ( wxConvUTF8 );
-
 	auto_ptr<Mp3Album> ma ( new Mp3Album() );
 	
 	BinaryFile *binaryfile;
-	binaryfile = new BinaryFile ( file.c_str() );
+	binaryfile = new BinaryFile ( fileWithSmilAttribs );
 	if ( !binaryfile->getData() )
 	{
-		error.Printf ( _ ( "Cannot open %s" ), file.c_str() );
+		error.Printf ( _ ( "Cannot open %s" ), fileWithSmilAttribs.c_str() );
 		return false;
 	}
     
@@ -800,7 +795,7 @@ bool WrapDaisy::run (
     return true;
 }
 
-wxString WrapDaisy::getLastError()
+const wxString &WrapDaisy::getLastError()
 {
     return error;   
 }
