@@ -52,7 +52,6 @@
 #include "xmldoc.h"
 #include "myhtmlpane.h"
 #include "xmlencodinghandler.h"
-#include "myipc.h"
 #include <wx/aui/framemanager.h>
 
 enum
@@ -121,6 +120,7 @@ enum
 	ID_VALIDATE_RELAX_NG,
 	ID_VALIDATE_W3C_SCHEMA,
 	ID_CREATE_SCHEMA,
+	ID_DTD_TO_SCHEMA,
 	ID_XPATH,
 	ID_XSLT,
 	ID_XSLT_TEI_FO,
@@ -166,6 +166,8 @@ enum
 	CONST_QUESTION
 };
 
+class MyServer;
+
 class MyApp : public wxApp
 {
 	public:
@@ -185,8 +187,6 @@ class MyApp : public wxApp
 	private:
 		wxSingleInstanceChecker *checker;
 		MyServer *server;
-		MyClient *client;
-		MyClientConnection *connection;
 		bool singleInstanceCheck;
 		int lang;
 		std::auto_ptr<wxFileConfig> config;
@@ -288,6 +288,7 @@ class MyFrame : public wxFrame
 		void OnValidateRelaxNG ( wxCommandEvent& event );
 		void OnValidateSchema ( wxCommandEvent& event );
 		void OnCreateSchema ( wxCommandEvent& event );
+		void OnDtd2Schema ( wxCommandEvent& event );
 		void OnXPath ( wxCommandEvent& event );
 		void OnXslt ( wxCommandEvent& event );
 		void OnValidatePreset ( wxCommandEvent& event );
@@ -330,7 +331,7 @@ class MyFrame : public wxFrame
 		// public to allow access from CommandPanel
 		XmlDoc *getActiveDocument();
 		void newDocument ( const wxString& s, const wxString& path = wxEmptyString, bool canSave = false );
-		void newDocument ( const std::string& s, const std::string& path = "", bool canSave = false );
+		void newDocument ( const std::string& s, const wxString& path = wxEmptyString, bool canSave = false );
 		void statusProgress ( const wxString& s );
 
 		// public to allow InsertPanel access
@@ -374,13 +375,24 @@ class MyFrame : public wxFrame
 		MyNotebook *mainBook;
 		MyHtmlPane *htmlReport;
 
-		std::string catalogPath, xslDtdPath, rssDtdPath, lzxDtdPath, xtmDtdPath,
+		wxString catalogPath, xslDtdPath, rssDtdPath, lzxDtdPath, xtmDtdPath,
 		xliffDtdPath, aspellDataPath, aspellDictPath;
-		std::pair<int, int> controlCoordinates;
 		std::map<std::string, std::map<std::string, std::set<std::string> > >
 		promptMap;
 		std::map<int, wxString> validationPresetMap;
+#ifdef __WXMSW__
+		struct MyCompare
+				: public std::binary_function<wxString, wxString, bool>
+		{
+			bool operator() ( const wxString &x, const wxString &y ) const
+			{
+				return x.CmpNoCase ( y ) < 0;
+			}
+		};
+		std::set<wxString, MyCompare> openFileSet;
+#else
 		std::set<wxString> openFileSet;
+#endif
 		std::set<wxString> openLargeFileSet;
 		std::vector<wxString> tempFileVector, fileQueue;
 		int documentCount,
@@ -525,9 +537,10 @@ class MyFrame : public wxFrame
 		    bool ignoreEncoding = false,
 		    bool isXml = true );
 		void removeUtf8Bom ( std::string& buffer );
-		std::string getAuxPath ( const std::string& fileName );
+		wxString getAuxPath ( const wxString& fileName );
 		wxMenuBar *getMenuBar();
 		wxToolBar *getToolBar();
+		void validatePaths();
 
 		DECLARE_EVENT_TABLE()
 };
