@@ -55,8 +55,8 @@ XmlCtrl::XmlCtrl (
     wxWindowID id,
     const char *buffer, // could be NULL
     size_t bufferLen,
-    const std::string& basePathParameter,
-    const std::string& auxPathParameter,
+    const wxString& basePathParameter,
+    const wxString& auxPathParameter,
     const wxPoint& position,
     const wxSize& size,
     long style
@@ -92,6 +92,11 @@ XmlCtrl::XmlCtrl (
 		bufferLen = strlen ( DEFAULT_XML_DECLARATION_UTF8 );
 	}
 
+#if wxCHECK_VERSION(2,9,0)
+	if ( type != FILE_TYPE_BINARY )
+		SetScrollWidthTracking ( true );
+#endif
+
 #if wxCHECK_VERSION(2,9,0)
 	AddTextRaw ( buffer, bufferLen );
 #else
@@ -125,6 +130,9 @@ XmlCtrl::XmlCtrl (
 		IndicatorSetStyle ( i, wxSTC_INDIC_HIDDEN );
 	IndicatorSetStyle ( 2, wxSTC_INDIC_SQUIGGLE );
 	IndicatorSetForeground ( 2, *wxRED );
+#if wxCHECK_VERSION(2,9,0)
+	SetIndicatorCurrent ( 2 );
+#endif
 }
 
 
@@ -1291,13 +1299,11 @@ bool XmlCtrl::canMoveLeftAt ( int pos )
 void XmlCtrl::adjustPosRight()
 {
 	int pos, max;
-	bool canInsert = false;
 	pos = GetCurrentPos();
 	max = GetLength();
 	for ( ; pos <= max; pos++ )
 		if ( canInsertAt ( pos ) )
 		{
-			canInsert = true;
 			break;
 		}
 	SetSelection ( pos, pos );
@@ -1306,7 +1312,6 @@ void XmlCtrl::adjustPosRight()
 void XmlCtrl::adjustPosLeft()
 {
 	int pos;
-	bool canInsert = false;
 	pos = GetCurrentPos() - 1;
 	if ( pos < 0 )
 	{
@@ -1316,7 +1321,6 @@ void XmlCtrl::adjustPosLeft()
 	for ( ; pos > 0; pos-- )
 		if ( canInsertAt ( pos ) )
 		{
-			canInsert = true;
 			break;
 		}
 	SetSelection ( pos, pos );
@@ -1954,14 +1958,14 @@ bool XmlCtrl::backgroundValidate()
 	
 	return backgroundValidate (
 		bufferUtf8.c_str(),
-		basePath.c_str(),
+		basePath,
 		bufferUtf8.size() );
 }
 
 bool XmlCtrl::backgroundValidate (
 				const char *buffer,
-				const char *system,
-                size_t bufferLen
+				const wxString &system,
+				size_t bufferLen
 				)
 {
 	if ( !validationRequired )
@@ -2008,8 +2012,12 @@ void XmlCtrl::setErrorIndicator ( int line, int column )
 	int length = endPos - startPos;
 	if ( length > 0 && length + startPos < GetLength() )
 	{
+#if wxCHECK_VERSION(2,9,0)
+		IndicatorFillRange ( startPos, length );
+#else
 		StartStyling ( startPos, wxSTC_INDIC2_MASK );
 		SetStyling ( length, wxSTC_INDIC2_MASK );
+#endif
 	}
 }
 
@@ -2026,8 +2034,12 @@ void XmlCtrl::clearErrorIndicators ( int maxLine )
 	length = ( maxLine ) ? GetLineEndPosition ( maxLine ) : length;
 	if ( end > 0 && length > end ) length = end;
 
+#if wxCHECK_VERSION(2,9,0)
+	IndicatorClearRange ( 0, length );
+#else
 	StartStyling ( 0, wxSTC_INDIC2_MASK );
 	SetStyling ( length, 0 );
+#endif
 }
 
 bool XmlCtrl::getValidationRequired()
@@ -2084,7 +2096,9 @@ int XmlCtrl::getTagType ( int pos )
 int XmlCtrl::getLexerStyleAt ( int pos )
 {
 	int style = GetStyleAt ( pos );
+#if !wxCHECK_VERSION(2,9,0)
 	style &= ~wxSTC_INDIC2_MASK;
+#endif
 	return style;
 }
 
