@@ -34,7 +34,6 @@ XmlSchemaGenerator::XmlSchemaGenerator ( bool inlineSimpleType /*= true*/)
 		: mInlineSimpleType ( inlineSimpleType )
 		, mGrammarType ( Grammar::SchemaGrammarType )
 {
-	WrapXerces::Init();
 }
 
 XmlSchemaGenerator::~XmlSchemaGenerator()
@@ -78,9 +77,10 @@ const wxString &XmlSchemaGenerator::generate ( Grammar::GrammarType grammarType,
 	if ( size > maxReservedSchemaBuffer ) size = maxReservedSchemaBuffer;
 	mSchema.Alloc ( size );
 
-	mSchema << _T("<?xml version=\"1.0\" encoding=\"UTF-8\"?>") << getEOL();
 	if ( mGrammarType == Grammar::SchemaGrammarType )
-		mSchema << _T("<xs:schema xmlns:xs=\"http://www.w3.org/2001/XMLSchema\" elementFormDefault=\"qualified\">")
+		mSchema << _T("<?xml version=\"1.0\" encoding=\"UTF-8\"?>")
+				<< getEOL()
+				<< _T("<xs:schema xmlns:xs=\"http://www.w3.org/2001/XMLSchema\" elementFormDefault=\"qualified\">")
 				<< getEOL();
 
 	xercesc::DOMElement *root = doc->getDocumentElement();
@@ -203,9 +203,8 @@ void XmlSchemaGenerator::generateData ( const wxString &elementName,
 			continue;
 		for ( attrItr = attrMap.begin(); attrItr != attrMap.end(); attrItr++ )
 		{
-			const static wxMBConvUTF16 conv;
-			if ( attrs->getNamedItem ( ( const XMLCh * ) ( const char * )
-					attrItr->first.mb_str ( conv ) ) == NULL )
+			if ( attrs->getNamedItem ( ( const XMLCh * )
+					WrapXerces::toString ( attrItr->first ).GetData() ) == NULL )
 			{
 				optAttrs.insert ( attrItr->first );
 			}
@@ -253,7 +252,7 @@ void XmlSchemaGenerator::generateSchema ( ElmtData &data, size_t nIndent )
 {
 	wxString &schema = data.schema;
 
-	if ( data.children.size() == 0 && data.attrMap.size() == 0 )
+	if ( data.children.empty() && data.attrMap.empty() )
 	{
 		if ( !mInlineSimpleType )
 		{
@@ -268,7 +267,7 @@ void XmlSchemaGenerator::generateSchema ( ElmtData &data, size_t nIndent )
 
 	addIndent ( schema, nIndent++ );
 	schema << _T("<xs:element name=\"") << data.name << _T("\">") << getEOL();
-	if ( data.children.size() > 0 )
+	if ( !data.children.empty() )
 	{
 		addIndent ( schema, nIndent++ );
 		schema << _T("<xs:complexType>") << getEOL();
@@ -306,8 +305,8 @@ void XmlSchemaGenerator::generateSchema ( ElmtData &data, size_t nIndent )
 			if ( mInlineSimpleType )
 			{ // Check if it's a simple type
 				const ElmtData *childElmt = &mElements[*seqItr];
-				if ( childElmt->children.size() == 0
-						&& childElmt->attrMap.size() == 0 )
+				if ( childElmt->children.empty()
+						&& childElmt->attrMap.empty() )
 				{
 					schema << _T("<xs:element name=\"") << *seqItr
 							<< _T("\" type=\"xs:string\"/>") << getEOL();
@@ -339,7 +338,7 @@ void XmlSchemaGenerator::generateSchema ( ElmtData &data, size_t nIndent )
 			schema << _T("</xs:choice>") << getEOL();
 		}
 	}
-	else if ( data.attrMap.size() != 0 )
+	else if ( !data.attrMap.empty() )
 	{
 		addIndent ( schema, nIndent++ );
 		schema << _T("<xs:complexType>") << getEOL();
